@@ -1,4 +1,4 @@
-# statusPage.py -- Plone status and browser launchers 
+# statusPage.py -- Plone status and browser launchers
 
 import wx
 
@@ -22,25 +22,25 @@ class statusPage(wx.Window):
         self.instance = kwargs.pop('instance')
         wx.Window.__init__(self, *args, **kwargs)
         self.ManageRoot = None
-        self.ViewPlone = None
-        
+        self.CreateViewPlone = None
+
         parent = args[0]
         panel = wx.Panel(self)
 
         self.staticBoxState = wx.StaticBox(
               label='Status', name='staticBoxState', parent=panel)
 
-        self.buttonChange = wx.Button(label='Start %s' % self.instance['name'], 
-                                      name='buttonChange', 
+        self.buttonChange = wx.Button(label='Start %s' % self.instance['name'],
+                                      name='buttonChange',
                                       parent=panel)
         self.Bind(wx.EVT_BUTTON, self.OnStatusChange, self.buttonChange)
 
         self.staticTextState = wx.StaticText(
-              label="Unknown state, determining...", 
+              label="Unknown state, determining...",
               name='staticTextState', parent=panel)
 
         sizer = wx.BoxSizer(wx.VERTICAL)
-        
+
         ssizer1 = wx.StaticBoxSizer(self.staticBoxState, wx.VERTICAL)
         ssizer1.Add(self.staticTextState, 0, wx.ALL, 10)
         ssizer1.Add(self.buttonChange, 0, wx.ALL, 10)
@@ -48,13 +48,13 @@ class statusPage(wx.Window):
 
         if self.instance.service == 'Zope':
             self.staticBoxWebControls = wx.StaticBox(
-                label='Site Management', 
-                name='staticBoxWebControls', 
+                label='Site Management',
+                name='staticBoxWebControls',
                 parent=panel)
 
-            self.ViewPlone = wx.Button(label='View Plone...', name='ViewPlone', 
+            self.CreateViewPlone = wx.Button(label='Create/View Plone site...', name='CreateViewPlone',
                                        parent=panel)
-            self.Bind(wx.EVT_BUTTON, self.OnViewPlone, self.ViewPlone)
+            self.Bind(wx.EVT_BUTTON, self.OnCreateViewPlone, self.CreateViewPlone)
 
             self.ManageRoot = wx.Button(label='Zope Management Interface...',
                                         name='ManageRoot',
@@ -62,7 +62,7 @@ class statusPage(wx.Window):
             self.Bind(wx.EVT_BUTTON, self.OnManageRoot, self.ManageRoot)
 
             ssizer2 = wx.StaticBoxSizer(self.staticBoxWebControls, wx.VERTICAL)
-            ssizer2.Add(self.ViewPlone, 0, wx.ALL, 10)
+            ssizer2.Add(self.CreateViewPlone, 0, wx.ALL, 10)
             ssizer2.Add(self.ManageRoot, 0, wx.ALL, 10)
             sizer.Add(ssizer2, 0, wx.ALL + wx.EXPAND, 10)
 
@@ -72,7 +72,7 @@ class statusPage(wx.Window):
         self.Fit()
 
         self._instance = status.Operate(self.instance)
-        
+
         # self.parent = parent
 
         self._lastStatus = None
@@ -84,18 +84,18 @@ class statusPage(wx.Window):
         self.timer = wx.Timer(self)
         self.Bind(wx.EVT_TIMER, self.OnUpdate, self.timer)
         self.DoChangeStatus(UNKNOWN)
-        
-        
+
+
     def OnStatusChange(self, event):
         if config.debug: print "Status button pushed"
-        
+
         if self._instance.getStatus(self) == STARTED:
             wx.PostEvent(self, status.UpdateEvent(STOPPING))
             self._instance.stop()
         else:
             wx.PostEvent(self, status.UpdateEvent(STARTING))
             self._instance.start()
-        
+
         event.Skip()
 
 
@@ -104,14 +104,14 @@ class statusPage(wx.Window):
         webbrowser.open(self.instance.getManageURL())
 
 
-    def OnViewPlone(self, event):
-        if config.debug: print "OnViewPlone"
+    def OnCreateViewPlone(self, event):
+        if config.debug: print "OnCreateViewPlone"
         webbrowser.open(self.instance.getURL())
 
 
     def postInitialize(self):
         """ this page is being shown """
-        
+
         if config.debug: print "postInitialize"
         # XXX: cursor set is not working.
         self.SetCursor(wx.StockCursor(wx.CURSOR_WAIT))
@@ -122,7 +122,7 @@ class statusPage(wx.Window):
 
     def postDeactivate(self):
         """ this page is being hidden """
-        
+
         if config.debug: print "postDeactivate"
         self.timer.Stop()
 
@@ -151,7 +151,7 @@ Error message: %s""" % err_msg
 
     def DoChangeStatus(self, action, msg=None):
         """ When you fire off a request... """
-        
+
         e = getattr(self, "_expected", [])
         if config.debug: print "DoChangeStatus: action %s, expected %s" % (action, e)
 
@@ -168,8 +168,8 @@ Error message: %s""" % err_msg
             self._expected = [STOPPED, STOPPING]
             if self.ManageRoot is not None:
                 self.ManageRoot.Enable(False)
-            if self.ViewPlone is not None:
-                self.ViewPlone.Enable(False)
+            if self.CreateViewPlone is not None:
+                self.CreateViewPlone.Enable(False)
 
         elif action == STARTING:
             self.buttonChange.Enable(False)
@@ -182,8 +182,8 @@ Error message: %s""" % err_msg
             self._expected = []
             if self.ManageRoot is not None:
                 self.ManageRoot.Enable(True)
-            if self.ViewPlone is not None:
-                self.ViewPlone.Enable(True)
+            if self.CreateViewPlone is not None:
+                self.CreateViewPlone.Enable(True)
 
         elif action == STOPPED:
             self.buttonChange.Enable(True)
@@ -191,8 +191,8 @@ Error message: %s""" % err_msg
             self._expected = []
             if self.ManageRoot is not None:
                 self.ManageRoot.Enable(False)
-            if self.ViewPlone is not None:
-                self.ViewPlone.Enable(False)
+            if self.CreateViewPlone is not None:
+                self.CreateViewPlone.Enable(False)
 
         elif action == UNKNOWN:
             self.buttonChange.Enable(False)
